Trait probability::distribution::Mean
[−]
[src]
pub trait Mean: Distribution {
fn mean(&self) -> f64;
}A distribution capable of computing the expected value.
The trait is applicable when the expected value exists, that is, finite.
Required Methods
Implementors
impl Mean for Bernoulliimpl Mean for Betaimpl Mean for Binomialimpl Mean for Categoricalimpl Mean for Exponentialimpl Mean for Gammaimpl Mean for Gaussianimpl Mean for Logisticimpl Mean for Lognormalimpl Mean for Triangularimpl Mean for Uniform